California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: JUNE 3, 2008 - SPECIAL RECALL ELECTION - SENATE DISTRICT 12 View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1300419 | DENHAM AGAINST THE RECALL, FRIENDS OF JEFF | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1304517 | WE DESERVE BETTER. YES ON THE RECALL OF JEFF DENHAM | SUPPORT